@@ -5,13 +5,19 @@ function FileSubmit(FileURL, ThumbURL, FileType) {
     var preview_id = 'image_' + input_id;
     var link_id = 'link_' + input_id;
     var help_id = 'help_' + input_id;
+    var clear_id = 'clear_' + input_id;
     input = opener.document.getElementById(input_id);
     preview = opener.document.getElementById(preview_id);
     link = opener.document.getElementById(link_id);
     help = opener.document.getElementById(help_id);
+    clear = opener.document.getElementById(clear_id);
+
     // set new value for input field
     input.value = FileURL;
 
+    // enable the clear "button"
+    $(clear).css("display", "inline");
+
     if (ThumbURL && FileType != "") {
         // selected file is an image and thumbnail is available:
         // display the preview-image (thumbnail)
